ExecutionServicesShutdownReport

Struct ExecutionServicesShutdownReport 

pub struct ExecutionServicesShutdownReport {
    pub blocking: ShutdownReport,
    pub cpu: ShutdownReport,
    pub tokio_blocking: ShutdownReport,
    pub io: ShutdownReport,
}
Aggregate report returned by super::ExecutionServices::shutdown_now.

Fields

blocking: ShutdownReport

Shutdown report for the blocking executor domain.

cpu: ShutdownReport

Shutdown report for the CPU executor domain.

tokio_blocking: ShutdownReport

Shutdown report for the Tokio blocking executor domain.

io: ShutdownReport

Shutdown report for the Tokio async IO executor domain.

Implementations

Source

impl ExecutionServicesShutdownReport

pub const fn total_queued(&self) -> usize

Returns the total queued task count across all execution domains.

Returns

The sum of every domain’s queued-task count.

pub const fn total_running(&self) -> usize

Returns the total running task count across all execution domains.

Returns

The sum of every domain’s running-task count.

pub const fn total_cancelled(&self) -> usize

Returns the total cancellation count across all execution domains.

Returns

The sum of every domain’s cancelled-task count.