pub struct ExecutionServicesStopReport {
pub blocking: StopReport,
pub cpu: StopReport,
pub tokio_blocking: StopReport,
pub io: StopReport,
}Expand description
Aggregate report returned by super::ExecutionServices::stop.
Fields
blocking: StopReportStop report for the blocking executor domain.
cpu: StopReportStop report for the CPU executor domain.
tokio_blocking: StopReportStop report for the Tokio blocking executor domain.
io: StopReportStop report for the Tokio async IO executor domain.
Implementations
Sourceimpl ExecutionServicesStopReport
impl ExecutionServicesStopReport
Sourcepub const fn total_queued(&self) -> usize
pub const fn total_queued(&self) -> usize
Returns the total queued task count across all execution domains.
Returns
The sum of every domain’s queued-task count.
Sourcepub const fn total_running(&self) -> usize
pub const fn total_running(&self) -> usize
Returns the total running task count across all execution domains.
Returns
The sum of every domain’s running-task count.
Sourcepub const fn total_cancelled(&self) -> usize
pub const fn total_cancelled(&self) -> usize
Returns the total cancellation count across all execution domains.
Returns
The sum of every domain’s cancelled-task count.