TokioExecutorService

Struct TokioExecutorService 

pub struct TokioExecutorService { /* private fields */ }
Tokio-backed service for submitted blocking tasks.

The service accepts fallible Runnable and Callable tasks and runs them through Tokio’s blocking task pool.

Implementations

Source

impl TokioExecutorService

pub fn new() -> TokioExecutorService

Creates a new service instance.

Returns

A Tokio-backed executor service.

Source

impl TokioExecutorService

pub fn await_termination(&self) -> Pin<Box<dyn Future<Output = ()> + Send + '_>>

Waits asynchronously until the service has terminated.

Returns

A future that resolves after shutdown or stop has been requested and all accepted blocking tasks have finished or been aborted before start.