pub struct TrackedTask<R, E> { /* private fields */ }Expand description
Result handle with active status tracking and pre-start cancellation.
Implementations
Sourceimpl<R, E> TrackedTask<R, E>
impl<R, E> TrackedTask<R, E>
Sourcepub fn get(self) -> Result<R, TaskExecutionError<E>>
pub fn get(self) -> Result<R, TaskExecutionError<E>>
Sourcepub fn try_get(self) -> TryGet<TrackedTask<R, E>, R, E>
pub fn try_get(self) -> TryGet<TrackedTask<R, E>, R, E>
Attempts to retrieve the final result without blocking.
Returns
A ready result or the pending tracked handle.
Sourcepub fn is_done(&self) -> bool
pub fn is_done(&self) -> bool
Returns whether the tracked task has installed a terminal state.
Returns
true after the task succeeds, fails, panics, is cancelled, or loses
its completion endpoint. The final result send may still be racing with
this status observation.
Sourcepub fn status(&self) -> TaskStatus
pub fn status(&self) -> TaskStatus
Sourcepub fn cancel(&self) -> CancelResult
pub fn cancel(&self) -> CancelResult