pub type BlockingExecutorService = ThreadPool;Expand description
Default managed service for synchronous tasks that may block an OS thread.
Aliased Type
pub struct BlockingExecutorService { /* private fields */ }pub type BlockingExecutorService = ThreadPool;Default managed service for synchronous tasks that may block an OS thread.
pub struct BlockingExecutorService { /* private fields */ }