pub struct ExecutionServicesBuilder { /* private fields */ }Expand description
Builder for ExecutionServices.
The builder exposes blocking-pool options by delegating to
BlockingExecutorServiceBuilder and CPU-pool options by delegating to
RayonExecutorServiceBuilder. Tokio-backed domains are created with their
default constructors because they do not currently expose custom builders.
Implementations
Sourceimpl ExecutionServicesBuilder
impl ExecutionServicesBuilder
Sourcepub fn blocking_pool_size(self, pool_size: usize) -> Self
pub fn blocking_pool_size(self, pool_size: usize) -> Self
Sourcepub fn blocking_core_pool_size(self, core_pool_size: usize) -> Self
pub fn blocking_core_pool_size(self, core_pool_size: usize) -> Self
Sourcepub fn blocking_maximum_pool_size(self, maximum_pool_size: usize) -> Self
pub fn blocking_maximum_pool_size(self, maximum_pool_size: usize) -> Self
Sourcepub fn blocking_queue_capacity(self, capacity: usize) -> Self
pub fn blocking_queue_capacity(self, capacity: usize) -> Self
Sourcepub fn blocking_unbounded_queue(self) -> Self
pub fn blocking_unbounded_queue(self) -> Self
Configures the blocking domain to use an unbounded queue.
Returns
This builder for fluent configuration.
Sourcepub fn blocking_thread_name_prefix(self, prefix: &str) -> Self
pub fn blocking_thread_name_prefix(self, prefix: &str) -> Self
Sourcepub fn blocking_stack_size(self, stack_size: usize) -> Self
pub fn blocking_stack_size(self, stack_size: usize) -> Self
Sourcepub fn blocking_keep_alive(self, keep_alive: Duration) -> Self
pub fn blocking_keep_alive(self, keep_alive: Duration) -> Self
Sourcepub fn blocking_allow_core_thread_timeout(self, allow: bool) -> Self
pub fn blocking_allow_core_thread_timeout(self, allow: bool) -> Self
Sourcepub fn blocking_prestart_core_threads(self) -> Self
pub fn blocking_prestart_core_threads(self) -> Self
Sourcepub fn cpu_threads(self, num_threads: usize) -> Self
pub fn cpu_threads(self, num_threads: usize) -> Self
Sourcepub fn cpu_thread_name_prefix(self, prefix: &str) -> Self
pub fn cpu_thread_name_prefix(self, prefix: &str) -> Self
Sourcepub fn cpu_stack_size(self, stack_size: usize) -> Self
pub fn cpu_stack_size(self, stack_size: usize) -> Self
Sourcepub fn build(self) -> Result<ExecutionServices, ExecutionServicesBuildError>
pub fn build(self) -> Result<ExecutionServices, ExecutionServicesBuildError>
Builds the configured execution-services facade.
Returns
Ok(ExecutionServices) if the blocking and CPU domains build
successfully.
Errors
Returns ExecutionServicesBuildError if either the blocking or CPU
domain rejects its builder configuration.