pub struct ExecutionServicesShutdownReport {
pub blocking: ShutdownReport,
pub cpu: ShutdownReport,
pub tokio_blocking: ShutdownReport,
pub io: ShutdownReport,
}Expand description
Aggregate report returned by super::ExecutionServices::shutdown_now.
Fields
blocking: ShutdownReportShutdown report for the blocking executor domain.
cpu: ShutdownReportShutdown report for the CPU executor domain.
tokio_blocking: ShutdownReportShutdown report for the Tokio blocking executor domain.
io: ShutdownReportShutdown report for the Tokio async IO executor domain.
Implementations
Sourceimpl ExecutionServicesShutdownReport
impl ExecutionServicesShutdownReport
Sourcepub const fn total_queued(&self) -> usize
pub const fn total_queued(&self) -> usize
Returns the total queued task count across all execution domains.
Returns
The sum of every domain’s queued-task count.
Sourcepub const fn total_running(&self) -> usize
pub const fn total_running(&self) -> usize
Returns the total running task count across all execution domains.
Returns
The sum of every domain’s running-task count.
Sourcepub const fn total_cancelled(&self) -> usize
pub const fn total_cancelled(&self) -> usize
Returns the total cancellation count across all execution domains.
Returns
The sum of every domain’s cancelled-task count.